package com.fs.live.controller;

import java.util.List;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.fs.common.annotation.Log;
import com.fs.common.core.controller.BaseController;
import com.fs.common.core.domain.AjaxResult;
import com.fs.common.enums.BusinessType;
import com.fs.live.domain.LiveOrderStatus;
import com.fs.live.service.ILiveOrderStatusService;
import com.fs.common.utils.poi.ExcelUtil;
import com.fs.common.core.page.TableDataInfo;

/**
 * 订单操作记录Controller
 * 
 * @author fs
 * @date 2025-07-08
 */
@RestController
@RequestMapping("/live/liveOrderStatus")
public class LiveOrderStatusController extends BaseController
{
    @Autowired
    private ILiveOrderStatusService liveOrderStatusService;

    /**
     * 查询订单操作记录列表
     */
    @PreAuthorize("@ss.hasPermi('live:liveOrderStatus:list')")
    @GetMapping("/list")
    public TableDataInfo list(LiveOrderStatus liveOrderStatus)
    {
        startPage();
        List<LiveOrderStatus> list = liveOrderStatusService.selectLiveOrderStatusList(liveOrderStatus);
        return getDataTable(list);
    }

    /**
     * 导出订单操作记录列表
     */
    @PreAuthorize("@ss.hasPermi('live:liveOrderStatus:export')")
    @Log(title = "订单操作记录", businessType = BusinessType.EXPORT)
    @GetMapping("/export")
    public AjaxResult export(LiveOrderStatus liveOrderStatus)
    {
        List<LiveOrderStatus> list = liveOrderStatusService.selectLiveOrderStatusList(liveOrderStatus);
        ExcelUtil<LiveOrderStatus> util = new ExcelUtil<LiveOrderStatus>(LiveOrderStatus.class);
        return util.exportExcel(list, "订单操作记录数据");
    }

    /**
     * 获取订单操作记录详细信息
     */
    @PreAuthorize("@ss.hasPermi('live:liveOrderStatus:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") String id)
    {
        return AjaxResult.success(liveOrderStatusService.selectLiveOrderStatusById(id));
    }

    /**
     * 新增订单操作记录
     */
    @PreAuthorize("@ss.hasPermi('live:liveOrderStatus:add')")
    @Log(title = "订单操作记录", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody LiveOrderStatus liveOrderStatus)
    {
        return toAjax(liveOrderStatusService.insertLiveOrderStatus(liveOrderStatus));
    }

    /**
     * 修改订单操作记录
     */
    @PreAuthorize("@ss.hasPermi('live:liveOrderStatus:edit')")
    @Log(title = "订单操作记录", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody LiveOrderStatus liveOrderStatus)
    {
        return toAjax(liveOrderStatusService.updateLiveOrderStatus(liveOrderStatus));
    }

    /**
     * 删除订单操作记录
     */
    @PreAuthorize("@ss.hasPermi('live:liveOrderStatus:remove')")
    @Log(title = "订单操作记录", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable String[] ids)
    {
        return toAjax(liveOrderStatusService.deleteLiveOrderStatusByIds(ids));
    }
}
