package com.fs.live.service.impl;

import java.util.List;
import com.fs.common.utils.DateUtils;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.fs.live.mapper.LiveOrderMapper;
import com.fs.live.domain.LiveOrder;
import com.fs.live.service.ILiveOrderService;

/**
 * 订单Service业务层处理
 * 
 * @author fs
 * @date 2025-07-08
 */
@Service
public class LiveOrderServiceImpl extends ServiceImpl<LiveOrderMapper, LiveOrder> implements ILiveOrderService {

    /**
     * 查询订单
     * 
     * @param orderId 订单主键
     * @return 订单
     */
    @Override
    public LiveOrder selectLiveOrderByOrderId(String orderId)
    {
        return baseMapper.selectLiveOrderByOrderId(orderId);
    }

    /**
     * 查询订单列表
     * 
     * @param liveOrder 订单
     * @return 订单
     */
    @Override
    public List<LiveOrder> selectLiveOrderList(LiveOrder liveOrder)
    {
        return baseMapper.selectLiveOrderList(liveOrder);
    }

    /**
     * 新增订单
     * 
     * @param liveOrder 订单
     * @return 结果
     */
    @Override
    public int insertLiveOrder(LiveOrder liveOrder)
    {
        liveOrder.setCreateTime(DateUtils.getNowDate());
        return baseMapper.insertLiveOrder(liveOrder);
    }

    /**
     * 修改订单
     * 
     * @param liveOrder 订单
     * @return 结果
     */
    @Override
    public int updateLiveOrder(LiveOrder liveOrder)
    {
        liveOrder.setUpdateTime(DateUtils.getNowDate());
        return baseMapper.updateLiveOrder(liveOrder);
    }

    /**
     * 批量删除订单
     * 
     * @param orderIds 需要删除的订单主键
     * @return 结果
     */
    @Override
    public int deleteLiveOrderByOrderIds(String[] orderIds)
    {
        return baseMapper.deleteLiveOrderByOrderIds(orderIds);
    }

    /**
     * 删除订单信息
     * 
     * @param orderId 订单主键
     * @return 结果
     */
    @Override
    public int deleteLiveOrderByOrderId(String orderId)
    {
        return baseMapper.deleteLiveOrderByOrderId(orderId);
    }
}
